package com.ruoyi.ai.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ruoyi.ai.domain.AiRechargeGiftGear;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * 充值赠送活动档位配置Service接口
 * 
 * @author shi
 * @date 2025-11-20
 */
public interface IAiRechargeGiftGearService {

    /**
     * 查询充值赠送活动档位配置
     * 
     * @param id 充值赠送活动档位配置主键
     * @return 充值赠送活动档位配置
     */
    AiRechargeGiftGear selectAiRechargeGiftGearById(Long id);

    /**
     * 查询充值赠送活动档位配置列表
     * 
     * @param aiRechargeGiftGear 充值赠送活动档位配置
     * @return 充值赠送活动档位配置集合
     */
    List<AiRechargeGiftGear> selectAiRechargeGiftGearList(AiRechargeGiftGear aiRechargeGiftGear);

    /**
     * 分页查询充值赠送活动档位配置列表
     *
     * @param aiRechargeGiftGear 充值赠送活动档位配置
     * @return 充值赠送活动档位配置集合
     */
    IPage<AiRechargeGiftGear> selectAiRechargeGiftGearPage(Page page, AiRechargeGiftGear aiRechargeGiftGear);

    /**
     * 新增充值赠送活动档位配置
     * 
     * @param aiRechargeGiftGear 充值赠送活动档位配置
     * @return 结果
     */
    int insertAiRechargeGiftGear(AiRechargeGiftGear aiRechargeGiftGear);

    /**
     * 修改充值赠送活动档位配置
     * 
     * @param aiRechargeGiftGear 充值赠送活动档位配置
     * @return 结果
     */
    int updateAiRechargeGiftGear(AiRechargeGiftGear aiRechargeGiftGear);

    /**
     * 批量删除充值赠送活动档位配置
     * 
     * @param ids 需要删除的充值赠送活动档位配置主键集合
     * @return 结果
     */
    int deleteAiRechargeGiftGearByIds(Long[] ids);

    /**
     * 删除充值赠送活动档位配置信息
     * 
     * @param id 充值赠送活动档位配置主键
     * @return 结果
     */
    int deleteAiRechargeGiftGearById(Long id);

    List<AiRechargeGiftGear> getGiftGear();
}
